==> qtjambi-bluetooth-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiBluetooth/QBluetoothSocket_shell.h <==
#ifndef QBLUETOOTHSOCKET_SHELL_H
#define QBLUETOOTHSOCKET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtBluetooth/qbluetoothsocket.h>
#include <QtJambi/QtJambiAPI>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothserviceinfo.h>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QBluetoothSocket_shell : public QBluetoothSocket, public QtJambiShellInterface
{
public:
    QBluetoothSocket_shell(QBluetoothServiceInfo::Protocol socketType0, QObject* parent1 = nullptr);
    QBluetoothSocket_shell(QObject* parent0 = nullptr);
    ~QBluetoothSocket_shell() override;

    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isSequential() const override;
    bool open(QIODevice::OpenMode mode0) override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxSize1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    bool seek(qint64 pos0) override;
    qint64 size() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 maxSize1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBluetoothSocket_access : public QBluetoothSocket
{
    void __qt_doDeviceDiscovery_cref_QBluetoothServiceInfo_QIODevice_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID service0, jint openMode1);
    void __qt_setSocketError_QBluetoothSocket_SocketError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint error0);
    void __qt_setSocketState_QBluetoothSocket_SocketState(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint state0);
    jlong __qt_bytesAvailable(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_bytesToWrite(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_canReadLine(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isSequential(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_readData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jbyteArray data0);
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jbyteArray data0);
};

#endif // QBLUETOOTHSOCKET_SHELL_H

==> qtjambi-bluetooth-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiBluetooth/QBluetoothSocket_shell.h <==
#ifndef QBLUETOOTHSOCKET_SHELL_H
#define QBLUETOOTHSOCKET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtBluetooth/qbluetoothsocket.h>
#include <QtJambi/QtJambiAPI>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtBluetooth/qbluetoothserviceinfo.h>
#include <QtBluetooth/qbluetoothuuid.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QBluetoothSocket_shell : public QBluetoothSocket, public QtJambiShellInterface
{
public:
    QBluetoothSocket_shell(QBluetoothServiceInfo::Protocol socketType0, QObject* parent1 = nullptr);
    QBluetoothSocket_shell(QObject* parent0 = nullptr);
    ~QBluetoothSocket_shell() override;

    bool atEnd() const override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isSequential() const override;
    bool open(QIODevice::OpenMode mode0) override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxSize1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    bool seek(qint64 pos0) override;
    qint64 size() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 maxSize1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBluetoothSocket_access : public QBluetoothSocket
{
    void __qt_doDeviceDiscovery_cref_QBluetoothServiceInfo_QIODevice_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID service0, jint openMode1);
    void __qt_setSocketError_QBluetoothSocket_SocketError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint error0);
    void __qt_setSocketState_QBluetoothSocket_SocketState(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint state0);
    jlong __qt_bytesAvailable(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_bytesToWrite(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_canReadLine(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isSequential(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_readData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QBLUETOOTHSOCKET_SHELL_H
